@echo off
REM cq2map.cmd -- compile a quake 2 map 
REM usage: "cq2map <mapname>"
REM
REM * You may place this file wherever you want, but make sure to adapt the
REM path settings below to your system!
REM
REM * You need qbsp3 for the BSP stage: http://home.insightbb.com/~gryndehl/q2compile/quake2.html
REM * You need qvis3 for the VIS stage: http://home.insightbb.com/~gryndehl/q2compile/quake2.html
REM * You need qrad3 for the VIS stage: http://home.insightbb.com/~gryndehl/q2compile/quake2.html
REM * You need arghrad for the RAD stage: http://arghrad.planetquake.gamespy.com/
REM
REM written by spirit - http://maps.sp1r1t.org

REM settings -- adapth these to your system!
@set QBSP3PATH="C:\games\quake2\tools\qbsp3.exe"
@set QVIS3PATH="C:\games\quake2\tools\qvis3.exe"
@set QRAD3PATH="C:\games\quake2\tools\qrad3.exe"
@set ARGHRADPATH="C:\Programme\GtkRadiant 1.5.0\arghrad.exe"
@set MAPPATH="C:\games\quake2\baseq2\maps"

REM more settings -- no need to mess with these, but you may.
REM The next line defines the arguments passed to qbsp3
@set QBSP3Q=
REM The next line defines the arguments passed to qvis3
@set QVIS3Q=
REM The next line defines the arguments passed to qrad3
@set QRAD3Q=
REM The next line defines the arguments passed to arghrad
@set ARGHRADQ=-ambient .2

REM don't mess with these, they are constructed from the settings above
@set MAPFILE=%MAPPATH%\%1.map
@set BSPFILE=%MAPPATH%\%1.bsp
@set APPTAG=[CQ2MAP]

echo %APPTAG% === compileq2map ===

REM check for args, bail out if missing
if {%1} == {} (call :HELP) & (goto :EOF)
if {%2} == {} (call :HELP) & (goto :EOF)


REM check quality and compile
if {%2} == {1} (call :Q1) & (goto :EOF)
if {%2} == {2} (call :Q2) & (goto :EOF)
if {%2} == {3} (call :Q3) & (goto :EOF)
if {%2} == {4} (call :Q4) & (goto :EOF)
if {%2} == {5} (call :Q5) & (goto :EOF)

REM comilation procedures
REM note that the first (Q1) will be assumed if no other is specified

:Q1
echo %APPTAG% compiling your map %1 at quality 1 (qbsp3, qvis3, arghrad).
%QBSP3PATH% %QBSP3Q% %MAPFILE%
%QVIS3PATH% %QVIS3Q% %BSPFILE%
%ARGHRADPATH% %ARGHRADQ% %BSPFILE%
echo %APPTAG% done at quality 1 (qbsp3, qvis3, arghrad).
goto :EOF

:Q2
echo %APPTAG% compiling your map %1 at quality 2 (qbsp3, qvis3, qrad3).
%QBSP3PATH% %QBSP3Q% %MAPFILE%
%QVIS3PATH% %QVIS3Q% %BSPFILE%
%QRAD3PATH% %QRAD3Q% %BSPFILE%
echo %APPTAG% done at quality 2 (qbsp3, qvis3, qrad3).
goto :EOF

:Q3
echo %APPTAG% compiling your map %1 at quality 3 (qbsp3, qvis3).
%QBSP3PATH% %QBSP3Q% %MAPFILE%
%QVIS3PATH% %QVIS3Q% %BSPFILE%
echo %APPTAG% done at quality 3 (qbsp3, qvis3).
goto :EOF

:Q4
echo %APPTAG% compiling your map %1 at quality 4 (qbsp3).
%QBSP3PATH% %QBSP3Q% %MAPFILE%
echo %APPTAG% done at quality 4 (qbsp3).
goto :EOF

:Q5
echo %APPTAG% compiling your map %1 at quality 5 (qbsp3, entities only).
%QBSP3PATH% -onlyents %MAPFILE%
echo %APPTAG% done at quality 5 (qbsp3, entities only).
goto :EOF


REM other functions
:HELP
echo USAGE
echo =====
echo cq2map mapname quality
echo mapname: name of your mapfile, no extension
echo quality: integer (1-5) that defines what to do:
echo          1: bsp, vis, rad with arghrad
echo          2: bsp, vis, rad with qrad3
echo          3: bsp, vis      (No lighting, fullbright!)
echo          4: bsp           (No lighting, fullbright! No vis, map runs slow in the game!)
echo          5: entities only (Only update entities, needs compiled bsp file.)
echo example: cq2map mymap 2
echo HINT: add " > logfile.txt" to the end of the command line to log the output to a file:
echo       cq2map mymap 2 > logfile.txt
echo HINT: Advanced users, you may want to edit the arguments passed to the tools in this file!
goto :EOF


REM we're done: bye bye, baby, bye bye
:EOF
echo %APPTAG% Done, Exiting. Check the output above for errors just to be sure.


